#line 2 "nrrdlex.C"

#line 4 "nrrdlex.C"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

    /* The c++ scanner is a mess. The FlexLexer.h header file relies on the
     * following macro. This is required in order to pass the c++-multiple-scanners
     * test in the regression suite. We get reports that it breaks inheritance.
     * We will address this in a future release of flex, or omit the C++ scanner
     * altogether.
     */
    #define yyFlexLexer nrrdFlexLexer

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
typedef uint64_t flex_uint64_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */
#include <iostream> 
#include <errno.h>
#include <cstdlib>
#include <cstring>
/* end standard C++ headers. */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t yyleng;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{

	std::istream* yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

void *nrrdalloc (yy_size_t  );
void *nrrdrealloc (void *,yy_size_t  );
void nrrdfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

#define yytext_ptr yytext

#include <FlexLexer.h>

int yyFlexLexer::yywrap() { return 1; }

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (yy_size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 105
#define YY_END_OF_BUFFER 106
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[359] =
    {   0,
        0,    0,    2,    2,  106,  104,  100,  103,  104,  104,
      104,   95,   99,   99,   99,   99,   99,   99,   99,   99,
       99,   99,   99,   99,   99,   99,   99,   99,   99,   99,
       99,  104,  104,    2,    1,  100,  101,    0,   95,   97,
       96,   95,   99,   99,   99,   99,   99,   99,   99,   99,
       99,   99,   99,   99,   99,   99,   99,   99,   99,   99,
       58,   99,   99,   99,   99,   99,   99,   99,   99,   99,
       99,   99,   99,   99,    4,   99,   99,   99,   99,   99,
       99,   99,   99,   99,   99,   99,   99,   99,   99,   99,
      102,    0,   98,    2,    0,    0,    0,   96,   99,   99,

       63,   99,   99,   60,   99,   99,   99,   99,   99,   99,
       99,   99,   99,   99,   99,   99,   99,   99,   99,   99,
       57,   29,   99,   99,   99,   99,   99,   69,   67,   99,
       99,   99,   99,    5,   66,   99,   53,   99,   99,   99,
       99,   99,   99,   99,   99,   54,   99,   99,   99,   99,
       99,   99,   99,   96,    0,   97,   99,   82,   99,   74,
       99,   89,   99,   22,   99,   11,   99,   99,   99,   99,
       99,   99,   99,   12,   99,   59,   99,   99,   99,   23,
       99,   99,   72,   99,   40,   85,   83,   90,   91,   99,
       99,   99,   99,   99,   99,   99,   50,   71,   99,   55,

       99,   19,   99,   37,   99,   99,   99,   99,   99,   56,
       99,   49,   99,   61,   99,   99,    3,   99,   99,   99,
       99,   99,   99,   47,   30,   35,   42,    0,   93,   99,
       99,   99,   99,   99,   99,   99,   99,   99,   99,   28,
       99,   79,   13,   99,   99,   25,   99,   26,   99,   14,
       99,   99,   99,   99,   99,   99,   99,   99,   99,   99,
       99,   99,   99,   48,   99,   62,    0,    0,    0,   24,
       92,   99,   64,   99,   99,   76,   70,   68,   16,   77,
       20,   99,   99,   38,    0,   99,   99,   99,   99,   32,
       99,   99,   99,   99,   99,   87,   65,   99,   99,   99,

       94,   99,   31,   36,   43,   99,   99,   99,   99,   99,
       99,    0,   27,   33,   45,   99,   99,   86,   84,   99,
       75,   99,   99,   99,   99,   52,   73,   41,    6,    7,
        8,    9,   10,   99,   80,   99,   39,    0,    0,   99,
       21,   51,   99,   18,   99,   99,   99,   81,   34,   46,
       99,   88,   15,   17,   99,   44,   78,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    5,    1,    5,    6,    1,    7,    8,    9,
       10,   11,   12,   13,   14,   15,   14,    1,    1,    1,
        1,    1,    1,    1,   16,   17,   18,   19,   20,   21,
       22,   23,   24,   25,   26,   27,   28,   29,   30,   31,
       25,   32,   33,   34,   35,   25,   36,   37,   38,   39,
        1,   40,    1,    1,   41,    1,   42,   43,   44,   45,

       46,   47,   48,   49,   50,   25,   51,   52,   53,   54,
       55,   56,   25,   57,   58,   59,   60,   25,   61,   62,
       63,   64,   65,    1,   66,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[67] =
    {   0,
        1,    1,    2,    1,    3,    4,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    6,    6,    6,    6,    7,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    1,
        1,    6,    6,    6,    6,    7,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    1,    1
    } ;

static yyconst flex_int16_t yy_base[367] =
    {   0,
        0,    0, 1080, 1073, 1060, 1098, 1055, 1098, 1051, 1047,
       60,   70,   80,   81,   91,  106,   89,   82,   85,   83,
       96, 1046,  104,  135,  147,  149,  141,  158,  204,  176,
      218,   69,  985,    0, 1098, 1047, 1098,  270,  166,   81,
      137,  280, 1042,  322,  174,  152,  169,  201,  101,  199,
      205,  210,  215,  160,  223,  290,  310,  295,  292,  244,
      291,  305,  314,  296,  306,  340,  346,  318,  347,  352,
      345,  350,  351,  360, 1040,  358,  197,  356,  355,  382,
      362,  377,  353,  383,  386,  385,  390,  389,  405,  411,
     1098,  979, 1098,    0, 1039, 1038,  457,  467,  434,  429,

     1036,  408,  195, 1035,  430,  477,  479,  482,  483,  484,
      485,  486,  487,  489,  491,  488,  497,  490,  493,  492,
     1034,  441,  496,  505,  510,  506,  522,  513,  516,  544,
      546,  518,  551, 1032,  547,  554, 1026,  548,  549,  553,
      552,  555,  571,  561,  578, 1023,  563,  572,  567,  574,
      587,  581,  591,  640,  649,  658,  668,  585,  593,  579,
       87, 1022,  669, 1021,  670, 1013,  671,  672,  673,  674,
      675,  676,  678, 1012,  677, 1011,   86,  239,  259,   98,
      679,  680,  681,  682,  698, 1010, 1009, 1008, 1005,  257,
      702,  707,  704,  724,  699,  723,  729, 1004,  732,  955,

      734,  949,  735,  438,  736,  738,  739,  741,  740,  889,
      749,  747,  753,  841,  758,  755,  840,  768,  760,  769,
      794,  782,  801,  837,  265,  267,  269,  391,  771,  775,
      777,  804,  805,  297,  780,  807,  810,  812,  811,  700,
      823,  697,  694,  816,  819,  693,  418,  381,  610,  691,
      814,  832,  815,  828,  846,  847,  848,  852,  845,  853,
      857,  872,  850,  690,  876,  639,  576,  833,  850, 1098,
      637,  882,  635,  883,  618,  634,  633,  630,  626,  881,
      624,  895,  874,  521,  859,  621,  354,  907,  905,  623,
      909,  913,  885,  908,  915,  495,  453,  893,  920,  922,

      436,  925, 1098, 1098, 1098,  923,  934,  975,  939,  930,
      932,  899, 1098,  921,  929,  966,  947,  431,  425,  954,
      422,  972,  951,  970,  983,  417,  348,  315,  311,  303,
      301,  299,  261,  985,  255,  989, 1098,  964,  967,  996,
      237,  231,  997,  181,  998, 1000, 1002,  172, 1098, 1098,
      991,  163,  161,  109, 1001,   94,   88, 1098, 1061, 1065,
     1067, 1074, 1081, 1084, 1089, 1092
    } ;

static yyconst flex_int16_t yy_def[367] =
    {   0,
      358,    1,  359,  359,  358,  358,  358,  358,  358,  360,
      358,  361,  361,  361,  361,  361,  361,  361,  361,  361,
      361,  361,  361,  361,  361,  361,  361,  361,  361,  361,
      361,  358,  362,  363,  358,  358,  358,  358,  360,  364,
      364,  361,  361,  361,  361,  361,  361,  361,  361,  361,
      361,  361,  361,  361,  361,  361,  361,  361,  361,  361,
      361,  361,  361,  361,  361,  361,  361,  361,  361,  361,
      361,  361,  361,  361,  361,  361,  361,  361,  361,  361,
      361,  361,  361,  361,  361,  361,  361,  361,  361,  361,
      358,  362,  358,  363,  365,  366,  358,  361,  361,  361,

      361,  361,  361,  361,  361,  361,  361,  361,  361,  361,
      361,  361,  361,  361,  361,  361,  361,  361,  361,  361,
      361,  361,  361,  361,  361,  361,  361,  361,  361,  361,
      361,  361,  361,  361,  361,  361,  361,  361,  361,  361,
      361,  361,  361,  361,  361,  361,  361,  361,  361,  361,
      361,  361,  361,  358,  358,  358,  361,  361,  361,  361,
      361,  361,  361,  361,  361,  361,  361,  361,  361,  361,
      361,  361,  361,  361,  361,  361,  361,  361,  361,  361,
      361,  361,  361,  361,  361,  361,  361,  361,  361,  361,
      361,  361,  361,  361,  361,  361,  361,  361,  361,  361,

      361,  361,  361,  361,  361,  361,  361,  361,  361,  361,
      361,  361,  361,  361,  361,  361,  361,  361,  361,  361,
      361,  361,  361,  361,  361,  361,  361,  358,  361,  361,
      361,  361,  361,  361,  361,  361,  361,  361,  361,  361,
      361,  361,  361,  361,  361,  361,  361,  361,  361,  361,
      361,  361,  361,  361,  361,  361,  361,  361,  361,  361,
      361,  361,  361,  361,  361,  361,  358,  358,  358,  358,
      361,  361,  361,  361,  361,  361,  361,  361,  361,  361,
      361,  361,  361,  361,  358,  361,  361,  361,  361,  361,
      361,  361,  361,  361,  361,  361,  361,  361,  361,  361,

      361,  361,  358,  358,  358,  361,  361,  361,  361,  361,
      361,  358,  358,  361,  361,  361,  361,  361,  361,  361,
      361,  361,  361,  361,  361,  361,  361,  361,  361,  361,
      361,  361,  361,  361,  361,  361,  358,  358,  358,  361,
      361,  361,  361,  361,  361,  361,  361,  361,  358,  358,
      361,  361,  361,  361,  361,  361,  361,    0,  358,  358,
      358,  358,  358,  358,  358,  358
    } ;

static yyconst flex_int16_t yy_nxt[1165] =
    {   0,
        6,    7,    8,    9,   10,   11,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   13,   14,   15,   16,   17,
       18,   19,   20,   21,   22,   23,   24,   25,   26,   27,
       22,   28,   29,   30,   31,   22,   22,   22,   22,   32,
        6,   13,   14,   15,   16,   17,   18,   19,   20,   21,
       23,   24,   25,   26,   27,   22,   28,   29,   30,   31,
       22,   22,   22,   22,   33,    6,   40,   40,   40,   40,
       40,   40,   40,   40,   40,   41,   42,   42,   42,   42,
       42,   42,   42,   42,   42,  358,  358,  358,  358,   44,
      358,  358,  358,  358,  358,  214,  358,   91,  225,  358,

       96,  358,   62,  358,   47,   59,  358,   48,   60,  358,
       51,  358,   45,   52,  358,   44,   46,   58,   49,   50,
       53,   54,   91,   61,   63,   55,   96,   64,   62,   56,
       47,   59,   48,   60,  103,   57,   51,   45,  228,   52,
      358,   46,   58,   49,   50,   53,  358,   54,   61,   63,
       65,   55,  358,   64,  358,   56,   95,  358,   66,  103,
       57,   73,   68,  358,   67,  358,  358,   74,  358,   75,
       69,   41,   76,   77,  358,  100,   65,  358,   70,  358,
       71,  358,   95,   72,   66,   95,  358,   73,   68,   67,
      101,   99,   74,  110,   75,   83,   69,   76,   84,   77,

      358,  100,  358,   70,  358,   71,  358,  104,   72,  358,
      358,   95,   85,   86,  160,  358,  101,   99,  110,   78,
      358,   83,  105,  358,   84,  108,   79,   80,  358,   81,
      102,  106,  137,  107,   82,   87,  358,   85,   86,  111,
      160,   88,  358,  109,  358,   78,   89,  226,  105,  358,
       90,  108,   79,   80,   81,  102,  106,  137,  107,   82,
      358,   87,  358,  234,  358,  111,  358,   88,  109,  227,
      358,   89,  358,  119,  358,   90,   40,   40,   40,   40,
       40,   40,   40,   40,   40,   41,   42,   42,   42,   42,
       42,   42,   42,   42,   42,  358,  358,  358,  119,   44,

      358,  358,  358,  275,  358,  267,  358,  268,  358,  269,
      358,  358,  116,  117,  120,  358,  358,  112,  118,  358,
      358,  113,  124,  358,  123,   44,   97,  358,   98,   98,
       98,   98,   98,   98,   98,   98,   98,  114,  116,  117,
      120,  121,  112,  118,  115,  358,  113,  122,  124,  123,
      358,  358,  358,  358,  128,  358,  358,  358,  358,  358,
      358,  358,  114,  358,  315,  358,  121,  358,  125,  115,
      130,  134,  122,  126,  127,  129,  132,  133,  135,  128,
      131,  136,  358,  138,  139,  142,  358,  358,  358,  144,
      358,  358,  143,  125,  358,  358,  130,  134,  126,  127,

      129,  132,  133,  140,  135,  131,  145,  136,  138,  139,
      358,  142,  148,  358,  144,  147,  358,  149,  143,  146,
      141,  285,  358,  358,  270,  159,  284,  358,  150,  140,
      358,  151,  145,  153,  358,  358,  358,  152,  148,  358,
      147,  358,  149,  358,  146,  141,  358,  247,  177,  270,
      178,  159,  248,  179,  150,  180,  151,  157,  358,  153,
      161,  158,  152,  154,  154,  154,  154,  154,  154,  154,
      154,  154,  358,   98,   98,   98,   98,   98,   98,   98,
       98,   98,  358,  157,  358,  161,  158,  358,  358,  358,
      358,  358,  358,  358,  358,  358,  358,  358,  358,  166,

      358,  358,  358,  162,  170,  168,  169,  171,  175,  174,
      358,  358,  163,  164,  181,  358,  165,  172,  358,  167,
      173,  358,  176,  358,  182,  166,  358,  358,  162,  183,
      170,  168,  169,  171,  175,  174,  190,  163,  164,  184,
      181,  165,  172,  185,  167,  186,  173,  176,  187,  358,
      182,  358,  358,  358,  358,  183,  358,  358,  358,  358,
      358,  312,  190,  188,  184,  189,  358,  191,  358,  185,
      186,  197,  358,  187,  192,  193,  358,  358,  194,  358,
      195,  196,  202,  358,  358,  198,  358,  203,  199,  188,
      358,  189,  358,  191,  200,  201,  358,  197,  358,  192,

      204,  193,  205,  194,  208,  195,  196,  206,  202,  303,
      198,  213,  211,  203,  199,  358,  207,  286,  212,  200,
      209,  201,  287,  358,  308,  204,  358,  205,  358,  358,
      208,  358,  206,  314,  303,  358,  213,  211,  358,  358,
      358,  207,  358,  212,  358,  209,  154,  154,  154,  154,
      154,  154,  154,  154,  154,  156,  156,  156,  156,  156,
      156,  156,  156,  156,  156,  156,  156,  156,  156,  156,
      156,  156,  156,  358,  358,  358,  358,  358,  358,  358,
      358,  358,  358,  358,  358,  358,  358,  358,  215,  216,
      219,  210,  217,  223,  222,  358,  358,  220,  358,  358,

      218,  221,  358,  358,  358,  358,  230,  358,  232,  358,
      224,  229,  358,  231,  215,  216,  219,  210,  217,  223,
      222,  235,  236,  220,  233,  218,  221,  238,  358,  358,
      237,  230,  240,  232,  358,  224,  229,  358,  231,  358,
      358,  358,  241,  358,  358,  358,  358,  235,  236,  233,
      239,  243,  358,  238,  358,  244,  237,  240,  358,  245,
      358,  242,  252,  358,  254,  358,  246,  251,  241,  249,
      250,  253,  255,  358,  358,  239,  358,  243,  257,  256,
      358,  244,  358,  259,  245,  358,  242,  358,  252,  258,
      254,  246,  251,  262,  249,  250,  253,  263,  255,  358,

      260,  261,  272,  257,  256,  265,  358,  271,  259,  358,
      358,  276,  358,  264,  258,  358,  358,  358,  262,  358,
      358,  358,  263,  273,  358,  260,  261,  272,  358,  266,
      280,  265,  271,  358,  274,  288,  276,  358,  278,  264,
      279,  281,  358,  277,  282,  358,  358,  283,  290,  273,
      358,  358,  358,  358,  266,  358,  280,  358,  358,  274,
      289,  288,  358,  278,  291,  279,  304,  281,  277,  282,
      293,  294,  283,  290,  292,  295,  298,  358,  297,  358,
      299,  358,  301,  305,  296,  289,  358,  358,  358,  291,
      358,  304,  313,  311,  358,  300,  293,  294,  358,  292,

      358,  295,  298,  297,  302,  306,  299,  301,  305,  296,
      358,  307,  358,  358,  358,  309,  310,  313,  358,  311,
      358,  300,  323,  320,  317,  358,  358,  358,  358,  302,
      358,  306,  337,  316,  358,  358,  307,  358,  321,  358,
      309,  318,  310,  322,  358,  319,  326,  323,  320,  324,
      317,  325,  358,  327,  358,  328,  358,  337,  316,  358,
      358,  338,  335,  321,  336,  341,  318,  334,  322,  339,
      319,  358,  326,  342,  324,  358,  325,  358,  327,  344,
      358,  328,  329,  330,  331,  332,  333,  335,  358,  336,
      358,  341,  334,  343,  358,  340,  358,  349,  345,  342,

      350,  358,  358,  358,  344,  358,  358,  358,  347,  358,
      358,  346,  356,  358,  358,  358,  358,  358,  358,  343,
      340,  348,  349,  345,  351,  350,  358,  358,  358,  352,
      353,  358,  354,  357,  347,  355,  346,  358,  356,  358,
      358,  358,  155,   97,   93,  358,  348,  358,   36,  351,
       93,  358,   38,   37,  352,  353,   36,  354,  357,  358,
      355,   34,   34,   34,   34,   34,   34,   34,   39,   39,
       43,   43,   43,   43,   92,   35,   92,   92,   92,   92,
       92,   94,   35,   94,   94,   94,   94,   94,   40,  358,
       40,  154,  358,  154,  156,  358,  156,    5,  358,  358,

      358,  358,  358,  358,  358,  358,  358,  358,  358,  358,
      358,  358,  358,  358,  358,  358,  358,  358,  358,  358,
      358,  358,  358,  358,  358,  358,  358,  358,  358,  358,
      358,  358,  358,  358,  358,  358,  358,  358,  358,  358,
      358,  358,  358,  358,  358,  358,  358,  358,  358,  358,
      358,  358,  358,  358,  358,  358,  358,  358,  358,  358,
      358,  358,  358,  358
    } ;

static yyconst flex_int16_t yy_chk[1165] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   13,   14,   18,   20,   12,
       19,  177,  161,  357,   17,  161,   15,   32,  177,  356,

       40,   21,   20,  180,   14,   18,   49,   14,   18,   23,
       15,   16,   13,   15,  354,   12,   13,   17,   14,   14,
       15,   16,   32,   19,   21,   16,   40,   23,   20,   16,
       14,   18,   14,   18,   49,   16,   15,   13,  180,   15,
       24,   13,   17,   14,   14,   15,   27,   16,   19,   21,
       24,   16,   25,   23,   26,   16,   41,   46,   24,   49,
       16,   27,   25,   28,   24,   54,  353,   27,  352,   27,
       25,   39,   27,   28,   47,   46,   24,  348,   26,   45,
       26,   30,   41,   26,   24,   39,  344,   27,   25,   24,
       47,   45,   27,   54,   27,   30,   25,   27,   30,   28,

      103,   46,   77,   26,   50,   26,   48,   50,   26,   29,
       51,   39,   30,   30,  103,   52,   47,   45,   54,   29,
       53,   30,   50,   31,   30,   52,   29,   29,   55,   29,
       48,   51,   77,   51,   29,   31,  342,   30,   30,   55,
      103,   31,  341,   53,  178,   29,   31,  178,   50,   60,
       31,   52,   29,   29,   29,   48,   51,   77,   51,   29,
      335,   31,  190,  190,  179,   55,  333,   31,   53,  179,
      225,   31,  226,   60,  227,   31,   38,   38,   38,   38,
       38,   38,   38,   38,   38,   42,   42,   42,   42,   42,
       42,   42,   42,   42,   42,   56,   61,   59,   60,   42,

       58,   64,  234,  234,  332,  225,  331,  226,  330,  227,
       62,   65,   58,   58,   61,   57,  329,   56,   59,   63,
      328,   56,   65,   68,   64,   42,   44,   44,   44,   44,
       44,   44,   44,   44,   44,   44,   44,   57,   58,   58,
       61,   62,   56,   59,   57,   66,   56,   63,   65,   64,
       71,   67,   69,  327,   68,   72,   73,   70,   83,  287,
       79,   78,   57,   76,  287,   74,   62,   81,   66,   57,
       70,   73,   63,   66,   67,   69,   71,   72,   74,   68,
       70,   76,   82,   78,   79,   81,  248,   80,   84,   83,
       86,   85,   82,   66,   88,   87,   70,   73,   66,   67,

       69,   71,   72,   80,   74,   70,   84,   76,   78,   79,
       89,   81,   87,  102,   83,   86,   90,   88,   82,   85,
       80,  248,  326,  247,  228,  102,  247,  321,   89,   80,
      319,   89,   84,   90,  100,  105,  318,   89,   87,   99,
       86,  301,   88,  204,   85,   80,  122,  204,  122,  228,
      122,  102,  204,  122,   89,  122,   89,   99,  297,   90,
      105,  100,   89,   97,   97,   97,   97,   97,   97,   97,
       97,   97,   98,   98,   98,   98,   98,   98,   98,   98,
       98,   98,  106,   99,  107,  105,  100,  108,  109,  110,
      111,  112,  113,  116,  114,  118,  115,  120,  119,  110,

      296,  123,  117,  106,  114,  112,  113,  115,  119,  118,
      124,  126,  107,  108,  123,  125,  109,  116,  128,  111,
      117,  129,  120,  132,  124,  110,  284,  127,  106,  125,
      114,  112,  113,  115,  119,  118,  132,  107,  108,  126,
      123,  109,  116,  127,  111,  128,  117,  120,  129,  130,
      124,  131,  135,  138,  139,  125,  133,  141,  140,  136,
      142,  284,  132,  130,  126,  131,  144,  133,  147,  127,
      128,  141,  149,  129,  135,  136,  143,  148,  138,  150,
      139,  140,  147,  145,  160,  142,  152,  148,  143,  130,
      158,  131,  151,  133,  144,  145,  153,  141,  159,  135,

      149,  136,  150,  138,  152,  139,  140,  150,  147,  267,
      142,  160,  158,  148,  143,  249,  151,  249,  159,  144,
      153,  145,  249,  275,  275,  149,  286,  150,  290,  281,
      152,  279,  150,  286,  267,  278,  160,  158,  277,  276,
      273,  151,  271,  159,  266,  153,  154,  154,  154,  154,
      154,  154,  154,  154,  154,  155,  155,  155,  155,  155,
      155,  155,  155,  155,  156,  156,  156,  156,  156,  156,
      156,  156,  156,  157,  163,  165,  167,  168,  169,  170,
      171,  172,  175,  173,  181,  182,  183,  184,  163,  165,
      169,  157,  167,  173,  172,  264,  250,  170,  246,  243,

      168,  171,  242,  185,  195,  240,  182,  191,  184,  193,
      175,  181,  192,  183,  163,  165,  169,  157,  167,  173,
      172,  191,  192,  170,  185,  168,  171,  193,  196,  194,
      192,  182,  195,  184,  197,  175,  181,  199,  183,  201,
      203,  205,  196,  206,  207,  209,  208,  191,  192,  185,
      194,  199,  212,  193,  211,  199,  192,  195,  213,  201,
      216,  197,  208,  215,  211,  219,  203,  207,  196,  205,
      206,  209,  211,  218,  220,  194,  229,  199,  213,  212,
      230,  199,  231,  216,  201,  235,  197,  222,  208,  215,
      211,  203,  207,  219,  205,  206,  209,  220,  211,  221,

      218,  218,  231,  213,  212,  222,  223,  230,  216,  232,
      233,  235,  236,  221,  215,  237,  239,  238,  219,  251,
      253,  244,  220,  232,  245,  218,  218,  231,  241,  223,
      239,  222,  230,  254,  233,  251,  235,  252,  237,  221,
      238,  241,  224,  236,  244,  217,  214,  245,  253,  232,
      259,  255,  256,  257,  223,  263,  239,  258,  260,  233,
      252,  251,  261,  237,  254,  238,  268,  241,  236,  244,
      256,  257,  245,  253,  255,  258,  260,  262,  259,  283,
      261,  265,  263,  269,  258,  252,  280,  272,  274,  254,
      293,  268,  285,  283,  210,  262,  256,  257,  298,  255,

      282,  258,  260,  259,  265,  272,  261,  263,  269,  258,
      289,  274,  288,  294,  291,  280,  282,  285,  292,  283,
      295,  262,  298,  293,  289,  299,  314,  300,  306,  265,
      302,  272,  312,  288,  315,  310,  274,  311,  294,  307,
      280,  291,  282,  295,  309,  292,  302,  298,  293,  299,
      289,  300,  317,  306,  202,  307,  323,  312,  288,  320,
      200,  314,  310,  294,  311,  317,  291,  309,  295,  315,
      292,  316,  302,  320,  299,  324,  300,  322,  306,  323,
      308,  307,  308,  308,  308,  308,  308,  310,  325,  311,
      334,  317,  309,  322,  336,  316,  351,  338,  324,  320,

      339,  340,  343,  345,  323,  346,  355,  347,  334,  198,
      189,  325,  351,  188,  187,  186,  176,  174,  166,  322,
      316,  336,  338,  324,  340,  339,  164,  162,  146,  343,
      345,  137,  346,  355,  334,  347,  325,  134,  351,  121,
      104,  101,   96,   95,   92,   75,  336,   43,   36,  340,
       33,   22,   10,    9,  343,  345,    7,  346,  355,    5,
      347,  359,  359,  359,  359,  359,  359,  359,  360,  360,
      361,  361,  361,  361,  362,    4,  362,  362,  362,  362,
      362,  363,    3,  363,  363,  363,  363,  363,  364,    0,
      364,  365,    0,  365,  366,    0,  366,  358,  358,  358,

      358,  358,  358,  358,  358,  358,  358,  358,  358,  358,
      358,  358,  358,  358,  358,  358,  358,  358,  358,  358,
      358,  358,  358,  358,  358,  358,  358,  358,  358,  358,
      358,  358,  358,  358,  358,  358,  358,  358,  358,  358,
      358,  358,  358,  358,  358,  358,  358,  358,  358,  358,
      358,  358,  358,  358,  358,  358,  358,  358,  358,  358,
      358,  358,  358,  358
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "nrrdlex.L"
/* Copyright (C) 1999-2015
 * Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 * For conditions of distribution and use, see copyright notice in "copyright"
 */
#line 11 "nrrdlex.L"
  #include <stdio.h>
  #include <stdlib.h>
  #include <string.h>

  #include "util.h"
  #include "nrrdparser.H"

  extern YYSTYPE* nrrdlval;
  extern nrrdFlexLexer* nrrdlexx;

/* rules */
#line 799 "nrrdlex.C"

#define INITIAL 0
#define DISCARD 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
#define ECHO LexerOutput( yytext, yyleng )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
\
	if ( (result = LexerInput( (char *) buf, max_size )) < 0 ) \
		YY_FATAL_ERROR( "input in flex scanner failed" );

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) LexerError( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1
#define YY_DECL int yyFlexLexer::yylex()
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 29 "nrrdlex.L"


#line 903 "nrrdlex.C"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = & std::cin;

		if ( ! yyout )
			yyout = & std::cout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 359 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 358 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 31 "nrrdlex.L"
{ // special case-- #\n
		  BEGIN INITIAL;
		  yyless(0);             // put back the terminator
		  strcpy(nrrdlval->str,""); // feed a blank string
		  return STRING;
		}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 38 "nrrdlex.L"
{  // Discard reset of line
		  BEGIN INITIAL;
		  int ll = yyleng <(NRRDPARSERSIZE-1) ? yyleng:(NRRDPARSERSIZE-1);
		  strncpy(nrrdlval->str,yytext,ll);
	          nrrdlval->str[ll] = '\0';
		  return STRING;
		}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 46 "nrrdlex.L"
{return DEBUG_;}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 47 "nrrdlex.L"
{return ON_;}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 48 "nrrdlex.L"
{return OFF_;}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 50 "nrrdlex.L"
{return NRRD0001_;}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 51 "nrrdlex.L"
{return NRRD0002_;}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 52 "nrrdlex.L"
{return NRRD0003_;}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 53 "nrrdlex.L"
{return NRRD0004_;}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 54 "nrrdlex.L"
{return NRRD0005_;}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 56 "nrrdlex.L"
{return DATA_;}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 57 "nrrdlex.L"
{return FILE_;}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 59 "nrrdlex.L"
{return SPACE_;}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 60 "nrrdlex.L"
{return UNITS_;}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 61 "nrrdlex.L"
{return DIMENSIONS_;}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 62 "nrrdlex.L"
{return ORIGIN_;}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 63 "nrrdlex.L"
{return DIRECTIONS_;}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 65 "nrrdlex.L"
{return DIMENSION_;}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 67 "nrrdlex.L"
{return TYPE_;}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 68 "nrrdlex.L"
{return SIGNED_;}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 69 "nrrdlex.L"
{return UNSIGNED_;}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 70 "nrrdlex.L"
{return CHAR_;}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 71 "nrrdlex.L"
{return INT8_;}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 72 "nrrdlex.L"
{return INT8_T_;}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 73 "nrrdlex.L"
{return UCHAR_;}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 74 "nrrdlex.L"
{return UINT8_;}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 75 "nrrdlex.L"
{return UINT8_T_;}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 76 "nrrdlex.L"
{return SHORT_;}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 77 "nrrdlex.L"
{return INT_;}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 78 "nrrdlex.L"
{return INT16_;}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 79 "nrrdlex.L"
{return INT16_T_;}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 80 "nrrdlex.L"
{return USHORT_;}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 81 "nrrdlex.L"
{return UINT16_;}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 82 "nrrdlex.L"
{return UINT16_T_;}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 83 "nrrdlex.L"
{return INT32_;}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 84 "nrrdlex.L"
{return INT32_T_;}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 85 "nrrdlex.L"
{return UINT_;}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 86 "nrrdlex.L"
{return UINT32_;}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 87 "nrrdlex.L"
{return UINT32_T_;}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 88 "nrrdlex.L"
{return LONG_;}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 89 "nrrdlex.L"
{return LONGLONG_;}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 90 "nrrdlex.L"
{return INT64_;}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 91 "nrrdlex.L"
{return INT64_T_;}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 92 "nrrdlex.L"
{return ULONGLONG_;}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 93 "nrrdlex.L"
{return UINT64_;}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 94 "nrrdlex.L"
{return UINT64_T_;}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 95 "nrrdlex.L"
{return FLOAT_;}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 96 "nrrdlex.L"
{return DOUBLE_;}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 98 "nrrdlex.L"
{return BLOCK_;}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 99 "nrrdlex.L"
{return SIZE_;}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 100 "nrrdlex.L"
{return BLOCKSIZE_;}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 102 "nrrdlex.L"
{return ENCODING_;}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 103 "nrrdlex.L"
{return RAW_;}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 104 "nrrdlex.L"
{return TXT_;}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 105 "nrrdlex.L"
{return TEXT_;}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 106 "nrrdlex.L"
{return ASCII_;}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 107 "nrrdlex.L"
{return HEX_;}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 108 "nrrdlex.L"
{return GZ_;}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 109 "nrrdlex.L"
{return GZIP_;}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 110 "nrrdlex.L"
{return BZ2_;}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 111 "nrrdlex.L"
{return BZIP2_;}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 113 "nrrdlex.L"
{return ENDIAN_;}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 114 "nrrdlex.L"
{return BIG_;}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 115 "nrrdlex.L"
{return LITTLE_;}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 117 "nrrdlex.L"
{return CONTENT_;}
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 119 "nrrdlex.L"
{return OLD_;}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 120 "nrrdlex.L"
{return MIN_;}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 121 "nrrdlex.L"
{return OLDMIN_;}
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 122 "nrrdlex.L"
{return MAX_;}
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 123 "nrrdlex.L"
{return OLDMAX_;}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 125 "nrrdlex.L"
{return SKIP_;}
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 126 "nrrdlex.L"
{return LINE_;}
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 127 "nrrdlex.L"
{return LINESKIP_;}
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 128 "nrrdlex.L"
{return BYTE_;}
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 129 "nrrdlex.L"
{return BYTESKIP_;}
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 131 "nrrdlex.L"
{return NUMBER_;}
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 133 "nrrdlex.L"
{return SAMPLE_;}
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 134 "nrrdlex.L"
{return SAMPLEUNITS_;}
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 136 "nrrdlex.L"
{return SIZES_;}
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 137 "nrrdlex.L"
{return SPACINGS_;}
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 138 "nrrdlex.L"
{return THICKNESSES_;}
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 139 "nrrdlex.L"
{return AXIS_;}
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 140 "nrrdlex.L"
{return MINS_;}
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 141 "nrrdlex.L"
{return AXISMINS_;}
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 142 "nrrdlex.L"
{return MAXS_;}
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 143 "nrrdlex.L"
{return AXISMAXS_;}
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 144 "nrrdlex.L"
{return CENTERS_;}
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 145 "nrrdlex.L"
{return CENTERINGS_;}
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 146 "nrrdlex.L"
{return CELL_;}
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 147 "nrrdlex.L"
{return NODE_;}
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 148 "nrrdlex.L"
{return NONE_;}
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 149 "nrrdlex.L"
{return LABELS_;}
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 150 "nrrdlex.L"
{return KINDS_;}
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 151 "nrrdlex.L"
{return DOMAINS_;}
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 153 "nrrdlex.L"
{ // Integer
		  nrrdlval->integer = atoi(yytext);
		  return INT;
		}
	YY_BREAK
case 96:
#line 159 "nrrdlex.L"
case 97:
YY_RULE_SETUP
#line 159 "nrrdlex.L"
{ // Real Number
		  nrrdlval->real = atof(yytext);
		  return REAL;
		}
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 165 "nrrdlex.L"
{ // Quoted String
		  int ll = (yyleng-2)<(NRRDPARSERSIZE-1) ? (yyleng-2):(NRRDPARSERSIZE-1);
		  strncpy(nrrdlval->str,yytext+1,ll); // skip the '{'
	          nrrdlval->str[ll] = '\0'; // Remove the '}'
		  return STRING;
		}
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 172 "nrrdlex.L"
{ // General String
		  int ll = yyleng <(NRRDPARSERSIZE-1) ? yyleng:(NRRDPARSERSIZE-1);
		  strncpy(nrrdlval->str,yytext,ll);
	          nrrdlval->str[ll] = '\0';
		  return STRING;
		}
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 179 "nrrdlex.L"
{ // White Spaces
		} 
	YY_BREAK
case 101:
/* rule 101 can match eol */
YY_RULE_SETUP
#line 182 "nrrdlex.L"
{ // windows line feed
		  return '\n';
		}
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 186 "nrrdlex.L"
{ // fake line feed
		  return '\n';
		}
	YY_BREAK
case 103:
/* rule 103 can match eol */
YY_RULE_SETUP
#line 190 "nrrdlex.L"
{ // linefeed
		  return '\n';
		}
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(DISCARD):
#line 194 "nrrdlex.L"
{ // eof
		  return EOF_;
		}
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 198 "nrrdlex.L"
{ // Else, return the char
		  return yytext[0];
		}
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 202 "nrrdlex.L"
ECHO;
	YY_BREAK
#line 1550 "nrrdlex.C"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* The contents of this function are C++ specific, so the () macro is not used.
 */
yyFlexLexer::yyFlexLexer( std::istream* arg_yyin, std::ostream* arg_yyout )
{
	yyin = arg_yyin;
	yyout = arg_yyout;
	yy_c_buf_p = 0;
	yy_init = 0;
	yy_start = 0;
	yy_flex_debug = 0;
	yylineno = 1;	// this will only get updated if %option yylineno

	yy_did_buffer_switch_on_eof = 0;

	yy_looking_for_trail_begin = 0;
	yy_more_flag = 0;
	yy_more_len = 0;
	yy_more_offset = yy_prev_more_offset = 0;

	yy_start_stack_ptr = yy_start_stack_depth = 0;
	yy_start_stack = NULL;

	yy_buffer_stack = 0;
	yy_buffer_stack_top = 0;
	yy_buffer_stack_max = 0;

	yy_state_buf = 0;

}

/* The contents of this function are C++ specific, so the () macro is not used.
 */
yyFlexLexer::~yyFlexLexer()
{
	delete [] yy_state_buf;
	nrrdfree(yy_start_stack  );
	yy_delete_buffer( YY_CURRENT_BUFFER );
	nrrdfree(yy_buffer_stack  );
}

/* The contents of this function are C++ specific, so the () macro is not used.
 */
void yyFlexLexer::switch_streams( std::istream* new_in, std::ostream* new_out )
{
	if ( new_in )
		{
		yy_delete_buffer( YY_CURRENT_BUFFER );
		yy_switch_to_buffer( yy_create_buffer( new_in, YY_BUF_SIZE  ) );
		}

	if ( new_out )
		yyout = new_out;
}

#ifdef YY_INTERACTIVE
size_t yyFlexLexer::LexerInput( char* buf, size_t /* max_size */ )
#else
size_t yyFlexLexer::LexerInput( char* buf, size_t max_size )
#endif
{
	if ( yyin->eof() || yyin->fail() )
		return 0;

#ifdef YY_INTERACTIVE
	yyin->get( buf[0] );

	if ( yyin->eof() )
		return 0;

	if ( yyin->bad() )
		return -1;

	return 1;

#else
	(void) yyin->read( buf, max_size );

	if ( yyin->bad() )
		return -1;
	else
		return yyin->gcount();
#endif
}

void yyFlexLexer::LexerOutput( const char* buf, size_t size )
{
	(void) yyout->write( buf, size );
}

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
int yyFlexLexer::yy_get_next_buffer()
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					nrrdrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) nrrdrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    yy_state_type yyFlexLexer::yy_get_previous_state()
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 359 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    yy_state_type yyFlexLexer::yy_try_NUL_trans( yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 359 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 358);

	return yy_is_jam ? 0 : yy_current_state;
}

    void yyFlexLexer::yyunput( int c, register char* yy_bp)
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register yy_size_t number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

    int yyFlexLexer::yyinput()
{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyFlexLexer::yyrestart( std::istream* input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yyFlexLexer::yy_switch_to_buffer( YY_BUFFER_STATE new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

    void yyFlexLexer::yy_load_buffer_state()
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yyFlexLexer::yy_create_buffer( std::istream* file, int size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) nrrdalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) nrrdalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yyFlexLexer::yy_delete_buffer( YY_BUFFER_STATE b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		nrrdfree((void *) b->yy_ch_buf  );

	nrrdfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    void yyFlexLexer::yy_init_buffer( YY_BUFFER_STATE b, std::istream* file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

	b->yy_is_interactive = 0;
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yyFlexLexer::yy_flush_buffer( YY_BUFFER_STATE b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yyFlexLexer::yypush_buffer_state (YY_BUFFER_STATE new_buffer)
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yyFlexLexer::yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
void yyFlexLexer::yyensure_buffer_stack(void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)nrrdalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)nrrdrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

    void yyFlexLexer::yy_push_state( int new_state )
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) nrrdalloc(new_size  );

		else
			(yy_start_stack) = (int *) nrrdrealloc((void *) (yy_start_stack),new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(new_state);
}

    void yyFlexLexer::yy_pop_state()
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

    int yyFlexLexer::yy_top_state()
{
    	return (yy_start_stack)[(yy_start_stack_ptr) - 1];
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

void yyFlexLexer::LexerError( yyconst char msg[] )
{
    	std::cerr << msg << std::endl;
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *nrrdalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *nrrdrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void nrrdfree (void * ptr )
{
	free( (char *) ptr );	/* see nrrdrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 202 "nrrdlex.L"



void nrrdDiscard(int doit)
{
  if (nrrdlexx)
    nrrdlexx->begin(DISCARD, doit);
}

void nrrdFlexLexer::begin(int which, int doit)
{
  BEGIN which;
  if (doit)
    yyless(0);
}

